@@ -30,12 +30,7 @@ check_rng_seed <- function(rng_seed) {
       "Actual value: ", rng_seed
     )
   }
-  if (!assertive::is_whole_number(rng_seed)) {
-    stop(
-      "'rng_seed' must be a whole number. \n",
-      "Actual value: ", rng_seed
-    )
-  }
+  check_true(beautier::is_one_int(rng_seed))
   if (rng_seed <= 0) {
     stop(
       "'rng_seed' should be one NA or one non-zero positive value.\n",
