@@ -11,7 +11,7 @@
 #' @author Richèl J.C. Bilderbeek
 #' @export
 create_temp_state_filename <- function() {
-  beastier::get_beastier_tempfilename(
+  get_beastier_tempfilename(
     pattern = "beast2_",
     fileext = ".xml.state"
   )
