@@ -33,18 +33,18 @@ extract_tracelog_filename_from_beast2_input_file <- function( # nolint indeed a
   input_filename
 ) {
   # Extract the tracelog file
-  testthat::expect_true(file.exists(input_filename))
+  check_true(file.exists(input_filename))
   text <- readr::read_lines(input_filename, progress = FALSE)
   tracelog_line <- stringr::str_subset(
     string = text,
     pattern = "<logger id=\"tracelog\""
   )
-  testthat::expect_equal(length(tracelog_line), 1)
+  check_true(length(tracelog_line) == 1)
   matches <- stringr::str_match(
     string = tracelog_line,
     pattern = "fileName=\\\"([:graph:]+)\\\" "
   )
-  testthat::expect_equal(ncol(matches), 2)
+  check_true(ncol(matches) == 2)
   tracelog_filename <- matches[1, 2]
   tracelog_filename
 }
