@@ -7,7 +7,7 @@
 #' get_beast2_options_filenames(beast2_options)
 #' @export
 get_beast2_options_filenames <- function(beast2_options) {
-  beastier::check_beast2_options(beast2_options)
+  check_beast2_options(beast2_options)
   c(
     beast2_options$input_filename,
     beast2_options$output_state_filename
