@@ -14,10 +14,10 @@
 #' @author Richèl J.C. Bilderbeek
 #' @export
 get_default_beast2_jar_path <- function(
-  beast2_folder = beastier::get_default_beast2_folder(),
+  beast2_folder = get_default_beast2_folder(),
   os = rappdirs::app_dir()$os
 ) {
-  beastier::check_os(os)
+  check_os(os)
   # Windows    : BEAST/lib/beast.jar                                            # nolint
   # Non-Windows: beast/lib/launcher.jar                                         # nolint
   beast_foldername <- "BEAST"
